@@ -6,9 +6,9 @@
   startup_msg <- paste("\n",
                        "Welcome to Lifebit's CloudOS R client \n",
                        "For Documentation visit - https://lifebit-ai.github.io/cloudos/ \n",
-                       "This package is under activate development. If you found any issues, \n",
+                       "This package is under active development. If you found any issues, \n",
                        "Please reach out here - https://github.com/lifebit-ai/cloudos/issues \n",
                        sep="")
   
   packageStartupMessage(startup_msg)
-}
\ No newline at end of file
+}
